@@ -8,6 +8,7 @@ from pyramid_debugtoolbar.compat import bytes_
 class DebugToolbarTests(unittest.TestCase):
     def setUp(self):
         self.config = testing.setUp()
+        self.config.registry.settings['mako.directories'] = []
 
     def tearDown(self):
         del self.config
@@ -18,7 +19,7 @@ class DebugToolbarTests(unittest.TestCase):
 
     def test_ctor_panel_is_up(self):
         request = Request.blank('/')
-        request.environ['HTTP_COOKIE'] = 'p_dt_active="id"'
+        request.environ['HTTP_COOKIE'] = 'pdtb_active="id"'
         toolbar = self._makeOne(request, [DummyPanelWithContent])
         self.assertEqual(len(toolbar.panels), 1)
         panel = toolbar.panels[0]
@@ -27,7 +28,7 @@ class DebugToolbarTests(unittest.TestCase):
 
     def test_ctor_panel_has_content(self):
         request = Request.blank('/')
-        request.environ['HTTP_COOKIE'] = 'p_dt_active="id"'
+        request.environ['HTTP_COOKIE'] = 'pdtb_active="id"'
         toolbar = self._makeOne(request, [DummyPanelWithContent])
         self.assertEqual(len(toolbar.panels), 1)
         panel = toolbar.panels[0]
@@ -45,7 +46,6 @@ class DebugToolbarTests(unittest.TestCase):
     def test_process_response_html(self):
         from pyramid_debugtoolbar.utils import ROOT_ROUTE_NAME
         from pyramid_debugtoolbar.utils import STATIC_PATH
-        self.config.include('pyramid_jinja2')
         self.config.add_static_view('_debugtoolbar/static',
                                     STATIC_PATH)
         self.config.add_route(ROOT_ROUTE_NAME, '/_debugtoolbar')
@@ -56,12 +56,11 @@ class DebugToolbarTests(unittest.TestCase):
         toolbar = self._makeOne(request, [DummyPanel])
         toolbar.process_response(response)
         self.assertTrue(response.processed)
-        self.failUnless(bytes_('div id="pDebug"') in response.app_iter[0])
+        self.assertTrue(bytes_('div id="pDebug"') in response.app_iter[0])
 
     def test_passing_of_button_style(self):
         from pyramid_debugtoolbar.utils import ROOT_ROUTE_NAME
         from pyramid_debugtoolbar.utils import STATIC_PATH
-        self.config.include('pyramid_jinja2')
         self.config.add_static_view('_debugtoolbar/static',
                                     STATIC_PATH)
         self.config.add_route(ROOT_ROUTE_NAME, '/_debugtoolbar')
@@ -74,7 +73,7 @@ class DebugToolbarTests(unittest.TestCase):
         toolbar = self._makeOne(request, [DummyPanel])
         toolbar.process_response(response)
         self.assertTrue(response.processed)
-        self.failUnless(bytes_('top:120px;zoom:50%') in response.app_iter[0])
+        self.assertTrue(bytes_('top:120px;zoom:50%') in response.app_iter[0])
 
 class Test_beforerender_subscriber(unittest.TestCase):
     def setUp(self):
@@ -131,10 +130,10 @@ class Test_toolbar_handler(unittest.TestCase):
         self.config = testing.setUp()
         self.config.registry.settings['debugtoolbar.enabled'] = True
         self.config.registry.settings['debugtoolbar.hosts'] = ['127.0.0.1']
+        self.config.registry.settings['mako.directories'] = []
         self.config.add_route(ROOT_ROUTE_NAME, '/_debug_toolbar')
         self.config.add_static_view('_debugtoolbar/static',
                                     STATIC_PATH)
-        self.config.include('pyramid_jinja2')
 
     def tearDown(self):
         testing.tearDown()
@@ -222,6 +221,7 @@ class Test_toolbar_handler(unittest.TestCase):
 class DummyPanel(object):
     is_active = False
     has_content = False
+    user_activate = False
 
     def __init__(self, request):
         self.request = request
